@@ -44,7 +44,8 @@ def _cns(tag):
 
 class GIRParser(object):
 
-    def __init__(self):
+    def __init__(self, types_only=False):
+        self._types_only = types_only
         self._shared_libraries = []
         self._includes = set()
         self._pkgconfig_packages = set()
@@ -149,8 +150,6 @@ class GIRParser(object):
             _corens('bitfield'): self._parse_enumeration_bitfield,
             _corens('callback'): self._parse_callback,
             _corens('class'): self._parse_object_interface,
-            _corens('constant'): self._parse_constant,
-            _corens('function'): self._parse_function,
             _corens('enumeration'): self._parse_enumeration_bitfield,
             _corens('interface'): self._parse_object_interface,
             _corens('record'): self._parse_record,
@@ -158,6 +157,10 @@ class GIRParser(object):
             _glibns('boxed'): self._parse_boxed,
             }
 
+        if not self._types_only:
+            parser_methods[_corens('constant')] = self._parse_constant
+            parser_methods[_corens('function')] = self._parse_function
+
         for node in ns.getchildren():
             method = parser_methods.get(node.tag)
             if method is not None:
@@ -179,10 +182,16 @@ class GIRParser(object):
         alias = ast.Alias(node.attrib['name'],
                       typeval,
                       node.attrib.get(_cns('type')))
+        self._parse_generic_attribs(node, alias)
         self._namespace.append(alias)
 
     def _parse_generic_attribs(self, node, obj):
         assert isinstance(obj, ast.Annotated)
+        introspectable = node.attrib.get('introspectable')
+        if introspectable:
+            obj.introspectable = int(introspectable) > 0
+        if self._types_only:
+            return
         doc = node.find(_corens('doc'))
         if doc is not None:
             obj.doc = doc.text
@@ -192,9 +201,9 @@ class GIRParser(object):
         deprecated = node.attrib.get('deprecated')
         if deprecated:
             obj.deprecated = deprecated
-        introspectable = node.attrib.get('introspectable')
-        if introspectable:
-            obj.introspectable = int(introspectable) > 0
+        deprecated_version = node.attrib.get('deprecated-version')
+        if deprecated_version:
+            obj.deprecated_version = deprecated_version
 
     def _parse_object_interface(self, node):
         parent = node.attrib.get('parent')
@@ -226,7 +235,8 @@ class GIRParser(object):
             obj.glib_type_struct = self._namespace.type_from_name(type_struct)
         self._namespace.append(obj)
 
-        ctor_args.append(node.attrib.get(_cns('type')))
+        if self._types_only:
+            return
         for iface in self._find_children(node, _corens('implements')):
             obj.interfaces.append(self._namespace.type_from_name(iface.attrib['name']))
         for iface in self._find_children(node, _corens('prerequisite')):
@@ -260,8 +270,6 @@ class GIRParser(object):
 
     def _parse_function(self, node):
         function = self._parse_function_common(node, ast.Function)
-        function.shadows = node.attrib.get('shadows', None)
-        function.shadowed_by = node.attrib.get('shadowed-by', None)
         self._namespace.append(function)
 
     def _parse_function_common(self, node, klass):
@@ -287,6 +295,9 @@ class GIRParser(object):
         else:
             assert False
 
+        func.shadows = node.attrib.get('shadows', None)
+        func.shadowed_by = node.attrib.get('shadowed-by', None)
+
         parameters_node = node.find(_corens('parameters'))
         if (parameters_node is not None):
             for paramnode in self._find_children(parameters_node, _corens('parameter')):
@@ -340,16 +351,17 @@ class GIRParser(object):
         if node.attrib.get('foreign') == '1':
             compound.foreign = True
         self._parse_generic_attribs(node, compound)
-        compound.fields.extend(self._parse_fields(node))
-        for method in self._find_children(node, _corens('method')):
-            compound.methods.append(
-                self._parse_function_common(method, ast.Function))
-        for func in self._find_children(node, _corens('function')):
-            compound.static_methods.append(
-                self._parse_function_common(func, ast.Function))
-        for ctor in self._find_children(node, _corens('constructor')):
-            compound.constructors.append(
-                self._parse_function_common(ctor, ast.Function))
+        if not self._types_only:
+            compound.fields.extend(self._parse_fields(node))
+            for method in self._find_children(node, _corens('method')):
+                compound.methods.append(
+                    self._parse_function_common(method, ast.Function))
+            for func in self._find_children(node, _corens('function')):
+                compound.static_methods.append(
+                    self._parse_function_common(func, ast.Function))
+            for ctor in self._find_children(node, _corens('constructor')):
+                compound.constructors.append(
+                    self._parse_function_common(ctor, ast.Function))
         return compound
 
     def _parse_record(self, node, anonymous=False):
@@ -444,6 +456,8 @@ class GIRParser(object):
                         c_symbol_prefix=node.attrib.get(_cns('symbol-prefix')))
         self._parse_generic_attribs(node, obj)
         self._namespace.append(obj)
+        if self._types_only:
+            return
         for method in self._find_children(node, _corens('method')):
             func = self._parse_function_common(method, ast.Function)
             func.is_method = True
@@ -480,6 +494,7 @@ class GIRParser(object):
                       node.attrib.get('writable') == '1',
                       node.attrib.get('bits'),
                       anonymous_node=anonymous_node)
+        field.private = node.attrib.get('private') == '1'
         self._parse_generic_attribs(node, field)
         return field
 
@@ -529,5 +544,7 @@ class GIRParser(object):
         self._parse_generic_attribs(node, obj)
         self._namespace.append(obj)
 
+        if self._types_only:
+            return
         for member in self._find_children(node, _corens('member')):
             members.append(self._parse_member(member))
